#!/bin/bash

# Make a complete javascript test environment consisting
# of rhino and jshint.

# ================================================================
# Useful command.
# ================================================================
function docmd() {
    local cmd="$*"
    echo
    echo "# ================================================================"
    echo "# CMD: $cmd"
    echo "# PWD: "`pwd`
    echo "# ================================================================"
    $cmd
    local st=$?
    if (( $st )) ; then
        echo "EXIT: Command exited with status $st (FAILED)."
	echo "      CMD: $cmd"
	exit 1
    else
        echo "EXIT: Command exited with status $st (PASSED)."
    fi
}

# ================================================================
# my-wget
# ================================================================
function my-wget() {
    local src="$1"
    local dst="$2"
    if [ ! -f $dst ] ; then
	docmd wget $src -O $dst
    fi
}

# ================================================================
# Setup
# ================================================================
medir=$(dirname -- $(readlink -f $0))
rootdir=$medir
rtf=$rootdir/rtf
archive=$rootdir/archives
export PATH="${rtf}/bin:${PATH}"
rds=('pkgs' 'rtf' 'archives')
for rd in ${rds[@]} ; do
    if [ ! -d $rd ] ; then
	docmd mkdir $rd
    fi
done

# ================================================================
# ant -- needed for rhino
# ================================================================
fn=apache-ant-1.8.4-bin.tar.bz2
arpath=$archive/$fn 
my-wget http://mirror.nexcess.net/apache/ant/binaries/$fn $arpath

if [ ! -d pkgs/apache-ant-1.8.4 ] ; then
    pushd pkgs
    docmd tar jxf $arpath
    popd
fi

# Very simple install, just copy over the bin and lib dirs.
if [ ! -f $rtf/bin/ant ] ; then
    pushd pkgs
    docmd rsync -avz apache-ant-1.8.4/bin $rtf/
    docmd rsync -avz apache-ant-1.8.4/lib $rtf/
    popd
fi
test -f $rtf/bin/ant

# ================================================================
# node (npm) -- needed for jhint
# ================================================================
fn=node-v0.8.4.tar.gz
arpath=$archive/$fn
my-wget http://nodejs.org/dist/v0.8.4/$fn $arpath

if [ ! -d pkgs/node-v0.8.4 ] ; then
    pushd pkgs
    docmd tar zxf $arpath
    popd
fi

if [ ! -f $rtf/bin/node ] ; then
    pushd pkgs/node-v0.8.4
    docmd ./configure --help
    docmd ./configure --prefix=$rtf
    docmd make
    docmd make install
    popd
fi
test -f $rtf/bin/node

# ================================================================
# jshint
# ================================================================
if [ ! -d pkgs/node-jshint ] ; then
    pushd pkgs
    docmd env GIT_SSL_NO_VERIFY=true git clone https://github.com/jshint/node-jshint.git
    popd
fi

if [ ! -f $rtf/bin/jshint ] ; then
    pushd pkgs/node-jshint
    docmd ./configure --prefix=$rtf
    popd
fi
test -f $rtf/bin/jshint

# ================================================================
# rhino -- javascript interpreter
# ================================================================
if [ ! -d pkgs/rhino ] ; then
    pushd pkgs
    docmd env GIT_SSL_NO_VERIFY=true git clone https://github.com/mozilla/rhino.git
    popd
fi

if [ ! -d rhino/build ] ; then
    pushd pkgs/rhino
    docmd ant
    docmd ant compile-all
    docmd ant jar
    popd
fi

if [ ! -d $rtf/rhino ] ; then
    docmd rsync -avz pkgs/rhino/build $rtf/rhino/
fi

if [ ! -d $rtf/bin/rhino ] ; then
    cat >$rtf/bin/rhino <<EOF
#!/bin/bash

# This should handle spaces in arguments:
#   rhino -e 'print("Hello, world!")''
i=0
argv=()
for arg in "\$@"; do
    argv[\$i]="\$arg"
    i=\$((i + 1))
done

# Now execute the command.
java -jar $rtf/rhino/build/rhino1_7R5pre/js.jar "\${argv[@]}"
EOF
    chmod a+x $rtf/bin/rhino
fi
test -f $rtf/rhino
test -f $rtf/bin/rhino

# ================================================================
# Installation tests.
# ================================================================
if [ ! -f .OK ] ; then
    docmd rhino -e 'print("hello");'
    cat >$$.js <<EOF
print("hello, world");
EOF
    docmd jshint $$.js
    rm -f $$.js
    touch .OK
fi




